#this import statement allows access to the karamba functions
import karamba


#this is called when you widget is initialized
def initWidget(widget):
    global wordcount, editcount, words
     
    words = readcount()
    wordcount = karamba.getThemeText(widget, "wordcount")
    karamba.changeText(widget, wordcount, str(words)+" words")
    
    editcount = karamba.createImage(widget, 14, 42, "imgs/edit.png")
    karamba.attachClickArea(widget, editcount)
    
    bar = karamba.getThemeBar(widget, "countbar")
    karamba.setBarValue(widget, bar, words)
    
    percent = karamba.getThemeText(widget, "percent")
    karamba.changeText(widget, percent, str((100.0/50000.0)*words)+"%")
    
    togo = karamba.getThemeText(widget, "togo")
    karamba.changeText(widget, togo, str(moredays())+" days")
    
    state(widget)
    karamba.acceptDrops(widget)

#this is called everytime your widget is updated
#the update inverval is specified in the .theme file
def widgetUpdated(widget):
    togo = karamba.getThemeText(widget, "togo")
    karamba.changeText(widget, togo, str(moredays())+" days")
    state(widget)

#This gets called everytime our widget is clicked.
#Notes:
#  widget = reference to our widget
#  x = x position (relative to our widget)
#  y = y position (relative to our widget)
#  botton = button clicked:
#                    1 = Left Mouse Button
#                    2 = Middle Mouse Button
#                    3 = Right Mouse Button, but this will never happen
#                        because the right mouse button brings up the
#                        Karamba menu.
#                    4,5 = Scroll wheel up and down
def widgetClicked(widget, x, y, button):
    pass

#This gets called everytime our widget is clicked.
#Notes
#  widget = reference to our widget
#  x = x position (relative to our widget)
#  y = y position (relative to our widget)
#  botton = button being held:
#                    0 = No Mouse Button
#                    1 = Left Mouse Button
#                    2 = Middle Mouse Button
#                    3 = Right Mouse Button, but this will never happen
#                        because the right mouse button brings up the
#                        Karamba menu.
def widgetMouseMoved(widget, x, y, button):
    #Warning:  Don't do anything too intensive here
    #You don't want to run some complex piece of code everytime the mouse moves
    pass


#This gets called when an item is clicked in a popup menu you have created.
#  menu = a reference to the menu
#  id = the number of the item that was clicked.
def menuItemClicked(widget, menu, id):
    pass

#This gets called when an item is clicked in the theme CONFIGURATION menu,
#not the popup menus that you create.
#  key = the reference to the configuration key that was changed
#  value = the new value (true or false) that was selected
def menuOptionChanged(widget, key, value):
    pass

#This gets called when a meter (image, text, etc) is clicked.
# NOTE you must use attachClickArea() to make a meter
# clickable.  
#  widget = reference to your theme
#  meter = the meter clicked
#  button = the button clicked (see widgetClicked for button numbers)
def meterClicked(widget, meter, button):
    global editcount, ok, no
    if meter == editcount:
	wantInput(widget)
    if meter == ok:
	hideInput(widget, "ok")
    if meter == no:
	hideInput(widget, "no")

#This gets called when a command you have executed with executeInteractive() outputs something
#to stdout.  This way you can get the output of for example kdialog without freezing up the widget
#waiting for kdialog to end.
#  widget = reference to your theme
#  pid = process number of the program outputting (use this if you execute more than out process)
#  output = the text the program outputted to stdout
def commandOutput(widget, pid, output):
    pass

#This gets called when an item is dropped on this widget.
# NOTE you have to call acceptDrops() before your widget will accept drops.
#  widget = reference to your theme
#  dropText = the text of the dropped item (probably a URL to it's location in KDE)
def itemDropped(widget, dropText):
    if strpos(dropText, ' ') == "y":
	y = 0
	lines = ['']
	for i in range(len(dropText)):
	    lines[y] = lines[y] + dropText[i]
	    if (dropText[i] == '\\') and (dropText[i+1] == 'n'):
		y += 1
		i += 1
		lines.append('')
    else:
        f = open(dropText[7:], "r")
        lines = f.readlines()
	f.close()
    c = 0
    for i in range(len(lines)):
	l = lines[i]
	for n in range(len(l)):
	    if l[n] == ' ':
		c += 1
    writecount(widget, c, 'a')


#This gets called when a new program is LOADING in KDE.  When it is done
#loading, startupRemoved() is called, followed by taskAdded().
#  widget = reference to your widget
#  task = A refence to the task that is starting.  
def startupAdded(widget, startup):
    pass

#This gets called when a new program is done LOADING in KDE.
#  widget = reference to your widget
#  task = A refence to the task that just finished loading.  
def startupRemoved(widget, startup):
    pass

#This is called every time a new task (program) is started in KDE.
#  widget = reference to your widget
#  task = A refence to the new task.  Call getTaskInfo() with this reference
#         to get the name, etc of this new task.
def taskAdded(widget, task):
    pass

#This is called everytime a task (program) is closed in KDE.
#  widget = reference to your widget
#  task = A refence to the task.  
def taskRemoved(widget, task):
    pass

#This is called everytime a different task gains focus (IE, the user clicks
#on a different window).  
#  widget = reference to your widget
#  task = A refence to the task.  Call getTaskInfo() with this reference
#         to get the name, etc of this new task.
def activeTaskChanged(widget, task):
    pass

def wantInput(widget):
    global inCount, ok, no, words
    inCount = karamba.createInputBox(widget, 20, 40, 130, 28, str(words))
    karamba.changeInputBoxBackgroundColor(widget, inCount, 255, 255, 255)
    karamba.changeInputBoxFrameColor(widget, inCount, 255, 0, 0)
    ok = karamba.createImage(widget, 60, 70, "imgs/ok.png")
    no = karamba.createImage(widget, 80, 70, "imgs/no.png")
    karamba.attachClickArea(widget, ok)
    karamba.attachClickArea(widget, no)
    
def hideInput(widget, huh):
    global inCount
    c = karamba.getInputBoxValue(widget, inCount)
    karamba.deleteInputBox(widget, inCount)
    karamba.deleteImage(widget, ok)
    karamba.deleteImage(widget, no)
    if huh == "ok":
	writecount(widget, c)
	
def writecount(widget, count, append=''):
    import os
    import datetime
    home = os.popen("echo $HOME").readline()[0:-1]
    file = home+"/.superkaramba/nanowords.cfg"
    
    if append == 'a':
	n = readcount()
	count += n
    f = open(file, "w")
    f.write(str(count))
    f.close()
    
    initWidget(widget)	
    
def readcount():
    import os
    home = os.popen("echo $HOME").readline()[0:-1]
    file = home+"/.superkaramba/nanowords.cfg"
    
    if os.path.isfile(file):
    	f = open(file, "r")
	n = f.readline()
    else:
	f = open(file, "w")
	f.write(str(0))
	n=0
    f.close()
    return int(n)
    
def moredays():
    import datetime
    now = datetime.date.today()
    end = datetime.date( 2005, 11, 30 )
    d = end-now
    return d.days

def state(widget):
    d = moredays
    if d > 30:
	s = "Take it cool"
    if d == 30:
	s = "BEGUN"
    if d < 30:
	s = "Start pulling your weight"
    if d < 25:
	s = "Relax, plenty of time"
    if d < 20:
	s = "Better start writing"
    if d < 15:
	s = "Hurry!"
    if d < 10:
	s = "Stop procrastinating!"
    if d < 5:
	s = "ZOMG"
    if d <= 0:
	s = "Gosh, you missed it"
    state = karamba.getThemeText(widget, "state")
    karamba.changeText(widget, state, s)
    
def strpos(hay, needle):
    for i in range(len(hay)):
	if hay[i] == needle:
	   return "y"
    return "n"

# This will be printed when the widget loads.
print "Loaded my python extension!"